==> mchange-commons-java-0.2.10-sources.jar: com/mchange/v2/log/MLogClasses.java <==
/*
 * Distributed as part of mchange-commons-java 0.2.9
 *
 * Copyright (C) 2015 Machinery For Change, Inc.
 *
 * Author: Steve Waldman <swaldman@mchange.com>
 *
 * This library is free software; you can redistribute it and/or modify
 * it under the terms of EITHER:
 *
 *     1) The GNU Lesser General Public License (LGPL), version 2.1, as 
 *        published by the Free Software Foundation
 *
 * OR
 *
 *     2) The Eclipse Public License (EPL), version 1.0
 *
 * You may choose which license to accept if you wish to redistribute
 * or modify this work. You may offer derivatives of this work
 * under the license you have chosen, or you may provide the same
 * choice of license which you have been offered here.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * You should have received copies of both LGPL v2.1 and EPL v1.0
 * along with this software; see the files LICENSE-EPL and LICENSE-LGPL.
 * If not, the text of these licenses are currently available at
 *
 * LGPL v2.1: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
 *  EPL v1.0: http://www.eclipse.org/org/documents/epl-v10.php 
 * 
 */

package com.mchange.v2.log;

import java.util.*;

public final class MLogClasses
{
    static final String LOG4J_CNAME = "com.mchange.v2.log.log4j.Log4jMLog";
    static final String SLF4J_CNAME = "com.mchange.v2.log.slf4j.Slf4jMLog";
    static final String JDK14_CNAME = "com.mchange.v2.log.jdk14logging.Jdk14MLog";

    final static String[] SEARCH_CLASSNAMES = { SLF4J_CNAME, LOG4J_CNAME, JDK14_CNAME };

    final static Map<String,String> ALIASES;

    static 
    {
	HashMap<String,String> map = new HashMap<String,String>();
	map.put("log4j", LOG4J_CNAME);
	map.put("slf4j", SLF4J_CNAME);
	map.put("jdk14", JDK14_CNAME);
	map.put("jul", JDK14_CNAME);
	map.put("java.util.logging", JDK14_CNAME);
	map.put("fallback", "com.mchange.v2.log.FallbackMLog");
	ALIASES = Collections.unmodifiableMap( map );
    }

    static String resolveIfAlias( String name )
    {
	String out = ALIASES.get( name.toLowerCase() );
	if ( out == null ) out = name;
	return out;
    }

    private MLogClasses()
    {}
}

==> mchange-commons-java-0.2.19-sources.jar: com/mchange/v2/log/MLogClasses.java <==
/*
 * Distributed as part of mchange-commons-java 0.2.11
 *
 * Copyright (C) 2015 Machinery For Change, Inc.
 *
 * Author: Steve Waldman <swaldman@mchange.com>
 *
 * This library is free software; you can redistribute it and/or modify
 * it under the terms of EITHER:
 *
 *     1) The GNU Lesser General Public License (LGPL), version 2.1, as 
 *        published by the Free Software Foundation
 *
 * OR
 *
 *     2) The Eclipse Public License (EPL), version 1.0
 *
 * You may choose which license to accept if you wish to redistribute
 * or modify this work. You may offer derivatives of this work
 * under the license you have chosen, or you may provide the same
 * choice of license which you have been offered here.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * You should have received copies of both LGPL v2.1 and EPL v1.0
 * along with this software; see the files LICENSE-EPL and LICENSE-LGPL.
 * If not, the text of these licenses are currently available at
 *
 * LGPL v2.1: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html
 *  EPL v1.0: http://www.eclipse.org/org/documents/epl-v10.php 
 * 
 */

package com.mchange.v2.log;

import java.util.*;

public final class MLogClasses
{
    static final String LOG4J_CNAME = "com.mchange.v2.log.log4j.Log4jMLog";
	static final String LOG4J2_CNAME = "com.mchange.v2.log.log4j2.Log4j2MLog";
    static final String SLF4J_CNAME = "com.mchange.v2.log.slf4j.Slf4jMLog";
    static final String JDK14_CNAME = "com.mchange.v2.log.jdk14logging.Jdk14MLog";

    final static String[] SEARCH_CLASSNAMES = { SLF4J_CNAME, LOG4J_CNAME, LOG4J2_CNAME, JDK14_CNAME };

    final static Map<String,String> ALIASES;

    static 
    {
	HashMap<String,String> map = new HashMap<String,String>();
	map.put("log4j", LOG4J_CNAME);
	map.put("log4j2", LOG4J2_CNAME);
	map.put("slf4j", SLF4J_CNAME);
	map.put("jdk14", JDK14_CNAME);
	map.put("jul", JDK14_CNAME);
	map.put("java.util.logging", JDK14_CNAME);
	map.put("fallback", "com.mchange.v2.log.FallbackMLog");
	ALIASES = Collections.unmodifiableMap( map );
    }

    static String resolveIfAlias( String name )
    {
	String out = ALIASES.get( name.toLowerCase() );
	if ( out == null ) out = name;
	return out;
    }

    private MLogClasses()
    {}
}
